# JSON:API Query Builder - Contribution Checklist

This document outlines the steps needed to prepare the JSON:API Query Builder module for contribution to Drupal.org.

## Current Status

The module is in good shape overall with:

- ✅ Module renamed from jsonapi_qb to jsonapi_query_builder
- ✅ Core functionality implemented
- ✅ React application built and integrated
- ✅ Comprehensive documentation
- ✅ Test scripts and code quality tools configured
- ✅ Required dependencies specified
- ✅ Proper Drupal coding standards applied
- ✅ Module structure follows Drupal best practices

## Pre-Contribution Checklist

### Module Information

- [ ] Update maintainer information in README.md (replace placeholders)
- [ ] Update organization information in README.md (replace placeholders)
- [ ] Create a MAINTAINERS.txt file with contributor information
- [ ] Review module description and ensure it accurately represents the module's purpose

### Code Quality

- [ ] Run and fix any remaining PHPStan issues (static analysis)
- [ ] Ensure 100% passing phpcs tests (current test shows 1 issue with newline at end of file)
- [ ] Review JavaScript code for any potential issues
- [ ] Verify React application builds successfully in a clean environment

### Testing

- [ ] Add more comprehensive PHP tests, especially for:
  - [ ] Controller functionality
  - [ ] Permission handling
  - [ ] Integration with JSON:API
- [ ] Add browser tests for UI interactions
- [ ] Ensure JavaScript tests pass
- [ ] Test installation on different Drupal versions (10.0, 10.1, etc.)

### Documentation

- [ ] Complete API documentation for developers extending the module
- [ ] Add more detailed examples of advanced usage scenarios
- [ ] Create a formal CHANGELOG.md file for tracking releases
- [ ] Add any additional screenshots if needed

### Drupal.org Preparation

- [ ] Create a project on Drupal.org (requires approved application)
- [ ] Set up Git repository on Drupal.org
- [ ] Create an initial release (1.0.0-alpha1 or similar)
- [ ] Write a release announcement
- [ ] Prepare project page with screenshots and description

### Final Checks

- [ ] Verify installation works via Composer
- [ ] Test module in a clean Drupal installation
- [ ] Ensure all dependencies are properly required
- [ ] Check for any hardcoded paths or references that might break in different environments
- [ ] Perform a security review
  - [ ] Check for proper input sanitization
  - [ ] Review JavaScript dependencies for vulnerabilities
  - [ ] Verify proper permission checks

## Next Steps

1. Complete the items on the checklist above
2. Apply for a project on Drupal.org using the Project Application form
3. Once approved, create the project and set up the Git repository
4. Make an initial release and announce it to the community
5. Monitor issues and provide support as needed

## Resources

- [Creating a project on Drupal.org](https://www.drupal.org/project/project_module)
- [Drupal.org Project Applications](https://www.drupal.org/project/project_module/applications)
- [Packaging a Drupal module](https://www.drupal.org/node/1978262)
- [Drupal Coding Standards](https://www.drupal.org/docs/develop/standards)
- [Drupal Security Best Practices](https://www.drupal.org/docs/security-in-drupal)
