#!/bin/bash

# Script to run lint checks for CI environment

# Exit on error
set -e

# Figure out the path to the repository root
REPO_PATH=$(pwd)
echo "Repository path: $REPO_PATH"

# Create directories for reports
mkdir -p reports

# Install required dependencies first
echo "Installing lint dependencies..."
composer global require php-parallel-lint/php-parallel-lint:^1.3 --no-interaction --no-progress
composer global require drupal/coder:^8.3 --no-interaction --no-progress 
composer global require phpstan/phpstan:^1.8 --no-interaction --no-progress

# Add composer global binaries to the PATH
export PATH="$HOME/.composer/vendor/bin:$PATH"

# List installed tools
echo "Checking if tools were properly installed:"
which parallel-lint || echo "parallel-lint not found"
which phpcs || echo "phpcs not found"
which phpstan || echo "phpstan not found"

# If tools are not in path, try another location
if ! which parallel-lint > /dev/null; then
  echo "Attempting to find linting tools in vendor directory..."
  composer require --dev php-parallel-lint/php-parallel-lint:^1.3 --no-interaction --no-progress
  composer require --dev drupal/coder:^8.3 --no-interaction --no-progress
  composer require --dev phpstan/phpstan:^1.8 --no-interaction --no-progress
  
  # Use local vendor bins if global install failed
  PARALLEL_LINT="./vendor/bin/parallel-lint"
  PHPCS="./vendor/bin/phpcs"
  PHPSTAN="./vendor/bin/phpstan"
else
  PARALLEL_LINT="parallel-lint"
  PHPCS="phpcs"
  PHPSTAN="phpstan"
fi

# Run the same lint tasks that are used locally
echo "Running parallel-lint..."
$PARALLEL_LINT --exclude vendor --exclude node_modules . > reports/parallel-lint-report.txt || true

echo "Running phpcs..."
$PHPCS --standard=phpcs.xml.dist > reports/phpcs-report.txt || true

echo "Running phpstan..."
$PHPSTAN analyse > reports/phpstan-report.txt || true

echo "Lint checks completed"