#!/bin/bash

# Script to run PHPUnit tests for CI environment

# Exit on error
set -e

echo "Running PHPUnit tests..."

# Set environment variables for Drupal testing
# Default values - these will be overridden if specific test suite needs them
export SIMPLETEST_BASE_URL=http://localhost:80
export SIMPLETEST_DB=sqlite://localhost/tmp/drupal_test.sqlite

# Get the directory where our Drupal test installation will be
MODULE_NAME="jsonapi_query_builder"
TEST_DIR="/tmp/drupal_test_phpunit_${MODULE_NAME}"

# Make sure the URLs are set correctly based on the test suite
if [[ "$*" == *"--testsuite=functional"* ]] || [[ "$*" == *"--testsuite=all"* ]]; then
  # If no URL is set explicitly and we're running functional tests, use the default Apache port
  if [[ -z "${SIMPLETEST_BASE_URL}" ]]; then
    export SIMPLETEST_BASE_URL=http://localhost
    echo "Setting SIMPLETEST_BASE_URL to http://localhost for functional tests"
  fi
  
  # Check if we need to start a built-in web server (don't start it if Apache is already running)
  if [[ "$SIMPLETEST_BASE_URL" == *":8888"* ]] && ! curl -s "http://localhost:8888" > /dev/null; then
    echo "Starting PHP built-in web server for functional tests..."
    cd "$TEST_DIR/web" || { echo "Drupal web directory not found!"; exit 1; }
    php -S 0.0.0.0:8888 .ht.router.php &
    SERVER_PID=$!
    echo "Web server started with PID: $SERVER_PID"
    
    # Give the server a moment to start up
    sleep 2
    echo "Testing web server..."
    curl -s "http://localhost:8888" > /dev/null || { echo "Web server not responding!"; }
    echo "Web server is running."
    
    # Make sure to kill the web server when the script exits
    trap "echo 'Stopping web server'; kill $SERVER_PID" EXIT
  fi
fi

# Explicitly set URL for unit tests
if [[ "$*" == *"--testsuite=unit"* ]]; then
  # Unit tests shouldn't need a real web server, but sometimes Drupal tries to access it anyway
  export SIMPLETEST_BASE_URL=http://localhost
  echo "Setting SIMPLETEST_BASE_URL to http://localhost for unit tests"
fi

# Determine output filename based on testsuite
if [[ "$*" == *"--testsuite=functional"* ]]; then
  RESULTS_FILE="test-results-functional.xml"
else
  RESULTS_FILE="test-results.xml"
fi

# Run tests with the same script used locally and capture the output in JUnit format
./scripts/run-phpunit-tests.sh --clean "$@" -- --log-junit "$RESULTS_FILE"

echo "PHPUnit tests completed - Results saved to $RESULTS_FILE"