#!/bin/bash

# Script to prepare CI environment by cleaning up /opt/drupal directory
# Run this before any other CI scripts

set -e  # Exit on error

echo "Preparing CI environment..."

# Check if /opt/drupal exists and clean it if needed
if [ -d "/opt/drupal" ]; then
  echo "Found /opt/drupal directory. Cleaning it..."
  
  # Try to remove all contents except .git
  find "/opt/drupal" -mindepth 1 -maxdepth 1 -not -name ".git" -exec rm -rf {} \; 2>/dev/null || true
  
  # Check if we succeeded
  REMAINING=$(find "/opt/drupal" -mindepth 1 -maxdepth 1 -not -name ".git" | wc -l)
  if [ "$REMAINING" -gt 0 ]; then
    echo "Warning: Could not clean all files in /opt/drupal. Trying with sudo..."
    sudo find "/opt/drupal" -mindepth 1 -maxdepth 1 -not -name ".git" -exec rm -rf {} \; 2>/dev/null || true
    
    # Check again
    REMAINING=$(find "/opt/drupal" -mindepth 1 -maxdepth 1 -not -name ".git" | wc -l)
    if [ "$REMAINING" -gt 0 ]; then
      echo "ERROR: Failed to clean /opt/drupal directory. Manual intervention required."
      exit 1
    fi
  fi
  
  echo "Successfully cleaned /opt/drupal directory."
else
  echo "/opt/drupal directory not found. No cleanup needed."
fi

# Also check for ./drupal directory in current working directory
if [ -d "./drupal" ]; then
  echo "Found ./drupal directory. Cleaning it..."
  rm -rf ./drupal
  echo "Successfully removed ./drupal directory."
fi

echo "CI environment preparation complete."