#!/bin/bash

# CI Drupal Setup - handles the special case where a CI environment has issues with /opt/drupal
# This script replaces the normal "composer create-project" command
# Usage: ./scripts/ci-drupal-setup.sh [optional_target_dir]

set -e  # Exit on error

TARGET_DIR="${1:-drupal}"
UNIQUE_DIR="drupal_temp_$(date +%s)"
DRUPAL_VERSION="^10.1"

echo "==> CI Drupal Setup: Creating temporary Drupal installation..."

# Create a temporary directory with a unique name
echo "Creating unique temporary directory: $UNIQUE_DIR"
mkdir -p "$UNIQUE_DIR"
cd "$UNIQUE_DIR"

# Create the project in this temporary directory
echo "Running composer create-project in temporary directory..."
composer create-project drupal/recommended-project:$DRUPAL_VERSION . --no-interaction --quiet

# Go back to original directory
cd ..

# If target directory exists, remove it completely
if [ -d "$TARGET_DIR" ]; then
  echo "Removing existing target directory: $TARGET_DIR"
  rm -rf "$TARGET_DIR"
fi

# Move the temporary directory to the target directory
echo "Moving Drupal installation to target directory: $TARGET_DIR"
mv "$UNIQUE_DIR" "$TARGET_DIR"

echo "==> CI Drupal Setup: Successfully created Drupal installation in $TARGET_DIR"

# Print success message
echo "You can now cd into $TARGET_DIR to continue setup"