<?php

namespace Drupal\Tests\jsonapi_query_builder\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests the JSON:API Query Builder interface.
 *
 * @group jsonapi_query_builder
 */
class JsonApiQueryBuilderTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'jsonapi_query_builder',
    'jsonapi',
    'jsonapi_schema',
    'node',
    'user',
  ];

  /**
   * Tests that the JSON:API Explorer page loads correctly.
   */
  public function testExplorerPageLoads() {
    // Create a user with permission to access the JSON:API explorer.
    $account = $this->drupalCreateUser(['access jsonapi explorer']);
    $this->drupalLogin($account);

    // Access the explorer page.
    $this->drupalGet('admin/jsonapi-explorer');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('JSON:API Query Builder');

    // Check for React app container.
    $this->assertSession()->elementExists('css', '#jsonapi-explorer-app');
  }

  /**
   * Tests access control for the JSON:API Explorer.
   */
  public function testExplorerAccessControl() {
    // Create a user without the required permission.
    $account = $this->drupalCreateUser(['access content']);
    $this->drupalLogin($account);

    // Try to access the explorer page.
    $this->drupalGet('admin/jsonapi-explorer');
    $this->assertSession()->statusCodeEquals(403);
  }

}
