<?php

namespace Drupal\Tests\jsonapi_query_builder\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\jsonapi_query_builder\Controller\ExplorerController;
use Drupal\Core\Url;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the JSON:API Query Builder controller.
 *
 * @group jsonapi_query_builder
 */
class JsonApiQueryBuilderUnitTest extends UnitTestCase {
  use ProphecyTrait;

  /**
   * Tests the explorer method of the controller.
   */
  public function testExplorerController() {
    // Mock the module handler.
    $module_handler = $this->prophesize(ModuleHandlerInterface::class);

    // Create a partial mock of the ExplorerController.
    $controller = $this->getMockBuilder(ExplorerController::class)
      ->setConstructorArgs([$module_handler->reveal()])
      ->onlyMethods(['t'])
      ->getMock();

    // Mock the t() method.
    $controller->expects($this->any())
      ->method('t')
      ->will($this->returnArgument(0));

    // Use reflection to replace the protected function.
    $reflection = new \ReflectionClass(Url::class);
    $method = $reflection->getMethod('fromRoute');
    $method->setAccessible(TRUE);

    // Create the render array.
    $result = $controller->explorer();

    // Check that the result is an array.
    $this->assertIsArray($result);

    // Check that the theme is set correctly.
    $this->assertEquals('jsonapi_explorer', $result['#theme']);

    // Check that the explorer library is attached.
    $this->assertContains('jsonapi_query_builder/explorer', $result['#attached']['library']);

    // Check that the drupalSettings are set.
    $this->assertArrayHasKey('jsonapiQueryBuilder', $result['#attached']['drupalSettings']);
  }

}
